from sanic import Sanic
from sanic_class import ChangeLedRoutes, BuzzerBeepRoutes, GetMediaRoutes
import logging

app = Sanic(__name__)

Log_Format = "%(levelname)s %(asctime)s - %(message)s"

logging.basicConfig(filename = "logfile.log",
                    filemode = "w",
                    format = Log_Format,
                    level = logging.ERROR)


app.add_route(ChangeLedRoutes.as_view(), "/change_led")
app.add_route(BuzzerBeepRoutes.as_view(), "/buzzer_beep")
app.add_route(GetMediaRoutes.as_view(), "/get_media")



if __name__ == "__main__":
    app.run(port=2000, workers=1)


"""sdk functions"""


def change_led():
    """function for change LED """
    response = "lead change"
    print(response)
    return response


def buzzer_beep():
    """function for Buzzer beep"""
    response = "buzzer beep"
    print(response)
    return response


def get_media():
    """function for get media"""
    response = "get media"
    print(response)
    return response



from sanic.views import HTTPMethodView
from sanic.response import json
from sanic.log import logger
from sdk_functions import change_led, buzzer_beep, get_media


class ChangeLedRoutes(HTTPMethodView):
    """class function for change led"""

    async def get(self, request):
        """filtering data on based created_at"""
        change_led()
        logger.info("change_led is successfully done")

        return json(
            {
                "status": "success",
                "message": "Led change"
            }
        )


class BuzzerBeepRoutes(HTTPMethodView):
    """class function for buzzer_beep"""

    async def get(self, request):
        """filtering data on based created_at"""
        buzzer_beep()
        logger.info("buzzer_beep is successfully done")

        return json(
            {
                "status": "success",
                "message": "buzzer_beep"
            }
        )


class GetMediaRoutes(HTTPMethodView):
    """class function for change led"""

    async def get(self, request):
        """filtering data on based created_at"""
        get_media()
        logger.info("get_media is successfully done")

        return json(
            {
                "status": "success",
                "message": "get_media"
            }
        )



from setuptools import setup, find_packages
import codecs
import os
from setuptools.command.install import install
from distutils.command.build_py import build_py as _build_py

VERSION = '0.0.6'
DESCRIPTION = 'SDK sanic application'

class CustomInstall(install):
    def run(self):
        install.run(self)
        print('overriden install command')

packages = ["keyo"]

# Setting up
setup(
    name="keyo_coral",
    version=VERSION,
    author="swalih",
    author_email="<swalihchungath@gmail.com>",
    cmdclass={'install': CustomInstall},
    description=DESCRIPTION,
    packages=packages,
    install_requires=['sanic'],
    keywords=['sanic','palm'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)